/*********************************************************************
*               SEGGER MICROCONTROLLER SYSTEME GmbH                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2007  SEGGER Microcontroller Systeme GmbH         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS version: 3.32o                                         *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : LED.c          (for MSC ModSDKM16C-CR8C23 development kit)
Purpose : LED interface
--------  END-OF-HEADER  ---------------------------------------------
*/

#define  LED_C
#include "LED.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** SFRs used for LED-Port **************************************/
/*      We define sfrs used here to keep the code generic without   */
/*      the need to include an sfr definition header file           */
 
#define _P2  (*(volatile unsigned char*)0x00E4)   /* Port P2 register */
#define _P2D (*(volatile unsigned char*)0x00E6)   /* Port P2 direction register */

#define _LED_PORT     (_P2)
#define _LED_PORT_DIR (_P2D)

/****** Assign LEDs to Ports ****************************************/

#define _LED0_BIT  (3)
#define _LED1_BIT  (4)
#define _LED0_MASK (1 << _LED0_BIT)
#define _LED1_MASK (1 << _LED1_BIT)
#define _LED_MASK_ALL (_LED0_MASK | _LED1_MASK)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       LED_Init()
*/
void LED_Init(void) {
  //
  // Initially switch off LEDs
  //
  _LED_PORT = 0;
  //
  // Enable output port for LEDS
  //
  _LED_PORT_DIR = 0xFF;
}

/*********************************************************************
*
*       LED switching routines
*/
void LED_SetLED0(void) {
  _LED_PORT |= _LED0_MASK;
}

void LED_ClrLED0(void) {
  _LED_PORT &= ~_LED0_MASK;
}

void LED_ToggleLED0(void) {
  _LED_PORT ^= _LED0_MASK;
}

void LED_SetLED1(void) {
  _LED_PORT |= _LED1_MASK;
}

void LED_ClrLED1(void) {
  _LED_PORT &= ~_LED1_MASK;
}

void LED_ToggleLED1(void) {
  _LED_PORT ^= _LED1_MASK;
}

/****** EOF *********************************************************/

